==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/kapacity/podminkyplanovanicontroller.php <==
<?php
/**
 * stanislav.elbl, 22.02.2019
 */

namespace RonPortal\Kapacity;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\Http\HtmlHeaders;
use Ron\MessageManager;
use Ron\MVC\HttpController;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use Ron\MVC\TextViewObject;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Obdobi;
use RonPortal\Prava;
use RonPortal\RonPortalXMLEvents;
use RonPortal\Rozdeleni;
use RonPortal\TypRozdeleni;
use RonPortal\XML\RonPortalXMLForm;


class PodminkyPlanovaniController extends HttpController
{
    /** @var Database */
    protected $database;

    /**
     * PodminkyPlanovaniController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
    }


    /**
     * @param PodminkyPlanovaniForm $form
     * @return \Ron\MVC\ViewObject
     * @throws \Exception
     */
    public function showForm($form) {
        if ($form ->editace) {
            $typRozdeleni = TypRozdeleni::getTypRozdeleni($this ->database, $form ->rozdeleni ->typ);
            Model::addData('typRozdeleni', $typRozdeleni);
        }

        return $form;
    }


    /**
     * @param int $pocatekObdobi
     * @param string $kodRozdeleni
     * @return Redirect
     */
    public function redirect($pocatekObdobi, $kodRozdeleni)
    {
        return new Redirect('?menuid=podminkyplanovani&obdobi=' . DateUtils::dateToUrlString($pocatekObdobi) . '&rozdeleni=' . StringUtils::htmlTextConvert($kodRozdeleni));
    }


    /**
     * @param string $eventName
     * @param string $context
     * @param Rozdeleni $rozdeleni
     * @param Obdobi $obdobi
     * @param \RonPortal\RonPortalDBRecord $record
     */
    public function executeEvents($eventName, $context, $rozdeleni, $obdobi, $record = null)
    {
        RonPortalXMLForm::xmlEvents($this ->database, $eventName,
            [
                'kodTypuRozdeleni' => $rozdeleni ->typ,
                'rozdeleni' => $rozdeleni ->kod,
                'obdobi' => $obdobi ->zacatek,
                'record' => $record
            ],
            $context);
    }


    /**
     * @throws \Exception
     */
    public function zpracujPost()
    {
        $typRozdeleni = KapacitySettings::typRozdeleniProVyber();
        $rozdeleni = Rozdeleni::loadRozdeleni($this ->database, $typRozdeleni, $_POST['rozdeleni']);
        $obdobi = Obdobi::vratObdobi($this->database, 'ADS', DateUtils::urlStringToDate($_POST['obdobi']));

        if (isset($_POST['cancel']) && $_POST['cancel']) {
            return $this ->redirect($obdobi ->zacatek, $rozdeleni ->kod);
        }

        $form = new PodminkyPlanovaniForm($this->database);
        // nacte originalni data
        $form->load($obdobi, $rozdeleni, true);

        $this ->executeEvents(RonPortalXMLEvents::KAPACITY_PODMINKY_BEFORE, '', $rozdeleni, $obdobi);
        $form->zpracujPost();
        $this ->executeEvents(RonPortalXMLEvents::KAPACITY_PODMINKY_AFTER, '', $rozdeleni, $obdobi);

        if (MessageManager::getInstance() ->isError()) {
            return $this ->showForm($form);
        }

        return $this ->redirect($obdobi ->zacatek, $rozdeleni ->kod);
    }


    public function editace()
    {
        $kodTypuRozdeleni = KapacitySettings::typRozdeleniProVyber();

        $rozdeleni = Rozdeleni::loadRozdeleni($this->database, $kodTypuRozdeleni, $_GET['rozdeleni']);
        $obdobi = Obdobi::vratObdobi($this->database, 'ADS', DateUtils::urlStringToDate($_GET['obdobi']));

        $form = new PodminkyPlanovaniForm($this->database);
        $form->load($obdobi, $rozdeleni, true);

        return $this ->showForm($form);
    }


    /**
     * @param int $uroven
     * @param bool $schvalit  Urcuje, jestli se ma schvalit (true), nebo odschvalit (false)
     * @return Redirect
     * @throws \Exception
     */
    public function nastavSchvaleni($uroven, $schvalit)
    {
        $kodTypuRozdeleni = KapacitySettings::typRozdeleniProVyber();

        $rozdeleni = Rozdeleni::loadRozdeleni($this->database, $kodTypuRozdeleni, $_GET['rozdeleni']);
        $obdobi = Obdobi::vratObdobi($this->database, 'ADS', DateUtils::urlStringToDate($_GET['obdobi']));

        try {
            SchvaleniPodminekPlanovani::nastavSchvaleniPodminek($this ->database,
                $rozdeleni, $obdobi, $uroven, $schvalit ? $obdobi->konec : null);
        } catch (\Exception $e) {
            MessageManager::addErrorMessage($e ->getMessage());
        }

        return $this->redirect($obdobi->zacatek, $rozdeleni->kod);
    }


    /**
     * @throws \Exception
     */
    public function handleAction($action)
    {
        $this ->addTranslationsScript('kapacity');
        HtmlHeaders::getInstance() ->addCss('css/s_kapacity.css', '?ver=' . HtmlHeaders::getInstance() ->versionId);

        TextManager::getInstance() ->loadStrings('kapacity.ini');

        if (isset($_POST['editacepodminek']) && (int)$_POST['editacepodminek']) {
            return $this ->zpracujPost();
        }

        if (isset($_GET['action'])  &&  $_GET['action']) {
            switch ($_GET['action']) {
                case 'editace' :
                    return $this->editace();

                    // schvaleni
                case 'schvalit1' :
                    return $this ->nastavSchvaleni(1, true);
                case 'schvalit2' :
                    return $this ->nastavSchvaleni(2, true);
                case 'schvalit3' :
                    return $this ->nastavSchvaleni(3, true);

                case 'zrusitschvaleni1' :
                    return $this ->nastavSchvaleni(1, false);
                case 'zrusitschvaleni2' :
                    return $this ->nastavSchvaleni(2, false);
                case 'zrusitschvaleni3' :
                    return $this ->nastavSchvaleni(3, false);
            }
        }

        $filter = new RonPortalFilterForm($this ->database, $action, true);
        $filter ->nastavObdobi(true, 'ADS', false); // jenOtevrene = false
        $filter ->header = TextManager::_('Minimalni_pocty_osob');

        $typRozdeleni = KapacitySettings::typRozdeleniProVyber();
        $filter ->f_pravarozdeleni = Prava::vratPrava('kapacity');
        $filter ->nastavRozdeleni(true, $typRozdeleni, 0, '', true);
        $filter ->loadData();

        Model::addViewObject($filter);

        $form = null;
        if ($filter ->kodRozdeleni) {
            $obdobi = Obdobi::vratObdobi($this->database, 'ADS', $filter->vybraneObdobiOd);
            $rozdeleni = Rozdeleni::loadRozdeleni($this->database, $typRozdeleni, $filter->kodRozdeleni);

            $form = new PodminkyPlanovaniForm($this->database);
            $form->load($obdobi, $rozdeleni);
        }


        if ($form) {
            return $this ->showForm($form);
        }


        return new TextViewObject('Nejdrive_vyberte_rozdeleni');
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/kapacity/podminkyplanovanicontroller.php <==
<?php
/**
 * stanislav.elbl, 22.02.2019
 */

namespace RonPortal\Kapacity;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\Http\HtmlHeaders;
use Ron\MessageManager;
use Ron\MVC\HttpController;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use Ron\MVC\TextViewObject;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\RonPortalFilterForm;
use RonPortal\Obdobi;
use RonPortal\Prava;
use RonPortal\RonPortalXMLEvents;
use RonPortal\Rozdeleni;
use RonPortal\TypRozdeleni;
use RonPortal\XML\RonPortalXMLForm;


class PodminkyPlanovaniController extends HttpController
{
    /** @var Database */
    protected $database;

    /**
     * PodminkyPlanovaniController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
    }


    /**
     * @param PodminkyPlanovaniForm $form
     * @return \Ron\MVC\ViewObject
     * @throws \Exception
     */
    public function showForm($form) {
        if ($form ->editace) {
            $typRozdeleni = TypRozdeleni::getTypRozdeleni($this ->database, $form ->rozdeleni ->typ);
            Model::addData('typRozdeleni', $typRozdeleni);
        }

        return $form;
    }


    /**
     * @param int $pocatekObdobi
     * @param string $kodRozdeleni
     * @return Redirect
     */
    public function redirect($pocatekObdobi, $kodRozdeleni)
    {
        return new Redirect('?menuid=podminkyplanovani&obdobi=' . DateUtils::dateToUrlString($pocatekObdobi) . '&rozdeleni=' . StringUtils::htmlTextConvert($kodRozdeleni));
    }


    /**
     * @param string $eventName
     * @param string $context
     * @param Rozdeleni $rozdeleni
     * @param Obdobi $obdobi
     * @param \RonPortal\RonPortalDBRecord $record
     */
    public function executeEvents($eventName, $context, $rozdeleni, $obdobi, $record = null)
    {
        RonPortalXMLForm::xmlEvents($this ->database, $eventName,
            [
                'kodTypuRozdeleni' => $rozdeleni ->typ,
                'rozdeleni' => $rozdeleni ->kod,
                'obdobi' => $obdobi ->zacatek,
                'record' => $record
            ],
            $context);
    }


    /**
     * @throws \Exception
     */
    public function zpracujPost()
    {
        $typRozdeleni = KapacitySettings::typRozdeleniProVyber();
        $rozdeleni = Rozdeleni::loadRozdeleni($this ->database, $typRozdeleni, $_POST['rozdeleni']);
        $obdobi = Obdobi::vratObdobi($this->database, 'ADS', DateUtils::urlStringToDate($_POST['obdobi']));

        if (isset($_POST['cancel']) && $_POST['cancel']) {
            return $this ->redirect($obdobi ->zacatek, $rozdeleni ->kod);
        }

        $form = new PodminkyPlanovaniForm($this->database);
        // nacte originalni data
        $form->load($obdobi, $rozdeleni, true);

        $this ->executeEvents(RonPortalXMLEvents::KAPACITY_PODMINKY_BEFORE, '', $rozdeleni, $obdobi);
        $form->zpracujPost();
        $this ->executeEvents(RonPortalXMLEvents::KAPACITY_PODMINKY_AFTER, '', $rozdeleni, $obdobi);

        if (MessageManager::getInstance() ->isError()) {
            return $this ->showForm($form);
        }

        return $this ->redirect($obdobi ->zacatek, $rozdeleni ->kod);
    }


    public function editace()
    {
        $kodTypuRozdeleni = KapacitySettings::typRozdeleniProVyber();

        $rozdeleni = Rozdeleni::loadRozdeleni($this->database, $kodTypuRozdeleni, $_GET['rozdeleni']);
        $obdobi = Obdobi::vratObdobi($this->database, 'ADS', DateUtils::urlStringToDate($_GET['obdobi']));

        $form = new PodminkyPlanovaniForm($this->database);
        $form->load($obdobi, $rozdeleni, true);

        return $this ->showForm($form);
    }


    /**
     * @param int $uroven
     * @param bool $schvalit  Urcuje, jestli se ma schvalit (true), nebo odschvalit (false)
     * @return Redirect
     * @throws \Exception
     */
    public function nastavSchvaleni($uroven, $schvalit)
    {
        $kodTypuRozdeleni = KapacitySettings::typRozdeleniProVyber();

        $rozdeleni = Rozdeleni::loadRozdeleni($this->database, $kodTypuRozdeleni, $_GET['rozdeleni']);
        $obdobi = Obdobi::vratObdobi($this->database, 'ADS', DateUtils::urlStringToDate($_GET['obdobi']));

        try {
            SchvaleniPodminekPlanovani::nastavSchvaleniPodminek($this ->database,
                $rozdeleni, $obdobi, $uroven, $schvalit ? $obdobi->konec : null);
        } catch (\Exception $e) {
            MessageManager::addErrorMessage($e ->getMessage());
        }

        return $this->redirect($obdobi->zacatek, $rozdeleni->kod);
    }


    /**
     * @throws \Exception
     */
    public function handleAction($action)
    {
        $this ->addTranslationsScript('kapacity');
        HtmlHeaders::getInstance() ->addCss('css/s_kapacity.css');

        TextManager::getInstance() ->loadStrings('kapacity.ini');

        if (isset($_POST['editacepodminek']) && (int)$_POST['editacepodminek']) {
            return $this ->zpracujPost();
        }

        if (isset($_GET['action'])  &&  $_GET['action']) {
            switch ($_GET['action']) {
                case 'editace' :
                    return $this->editace();

                    // schvaleni
                case 'schvalit1' :
                    return $this ->nastavSchvaleni(1, true);
                case 'schvalit2' :
                    return $this ->nastavSchvaleni(2, true);
                case 'schvalit3' :
                    return $this ->nastavSchvaleni(3, true);

                case 'zrusitschvaleni1' :
                    return $this ->nastavSchvaleni(1, false);
                case 'zrusitschvaleni2' :
                    return $this ->nastavSchvaleni(2, false);
                case 'zrusitschvaleni3' :
                    return $this ->nastavSchvaleni(3, false);
            }
        }

        $filterForm = new RonPortalFilterForm($this ->database, $action, true);
        $filterForm ->nastavObdobi(true, 'ADS', false); // jenOtevrene = false
        $filterForm ->header = TextManager::_('Minimalni_pocty_osob');

        $typRozdeleni = KapacitySettings::typRozdeleniProVyber();
        ($filterForm ->addFilterRozdeleni('rozdeleni', $typRozdeleni))
            ->setSessionName('ads_rozdeleni_' . $typRozdeleni)
            ->setPouzitPopisTypuRozdeleni(true)
            ->setJenVlastniRozdeleni(0)
            ->setPrava(Prava::vratPrava('kapacity'));

//        $filterForm ->f_pravarozdeleni = Prava::vratPrava('kapacity');
//        $filterForm ->nastavRozdeleni(true, $typRozdeleni, 0, '', true);
        $filterForm ->loadData();

        Model::addViewObject($filterForm);

        $form = null;
        $kodRozdeleni = $filterForm ->getFilterValue('rozdeleni');
        if ($kodRozdeleni) {
            $obdobi = Obdobi::vratObdobi($this->database, 'ADS', $filterForm->vybraneObdobiOd);
            $rozdeleni = Rozdeleni::loadRozdeleni($this->database, $typRozdeleni, $kodRozdeleni);

            $form = new PodminkyPlanovaniForm($this->database);
            $form->load($obdobi, $rozdeleni);
        }


        if ($form) {
            return $this ->showForm($form);
        }


        return new TextViewObject('Nejdrive_vyberte_rozdeleni');
    }

}
